import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { NgxEchartsDirective, provideEchartsCore } from 'ngx-echarts';
import * as echarts from 'echarts';


@Component({
  selector: 'app-page-home',
  standalone: true,
  imports: [
    CommonModule,
    FormsModule,
    NgxEchartsDirective // 使用指令而不是模块
  ],
  providers: [
  provideEchartsCore({
    echarts: () => import('echarts')
  })
],
  templateUrl: './page-home.html',
  styleUrls: ['./page-home.scss']
})
export class PageHome implements OnInit {
  chartOptions: any;
  showModal = false;
  currentSales: any = {};
  activeFilter: string | null = null;
  performanceRange = 50;
  
// 在组件类中添加权限数据
permissions = [
  {
    icon: 'users',
    title: '客户数据访问',
    description: '允许查看和编辑客户信息',
    enabled: true
  },
  {
    icon: 'tags',
    title: '报价修改权限',
    description: '允许修改套餐价格和优惠',
    enabled: this.currentSales.level !== 'rookie'
  },
  {
    icon: 'robot',
    title: 'AI陪练系统',
    description: '使用AI虚拟陪练功能',
    enabled: true
  },
  {
    icon: 'chart-pie',
    title: '高级分析报告',
    description: '访问详细客户分析报告',
    enabled: ['gold', 'platinum', 'diamond'].includes(this.currentSales.level)
  },
  {
    icon: 'globe',
    title: '跨区域客户',
    description: '访问和分配跨区域客户',
    enabled: ['platinum', 'diamond'].includes(this.currentSales.level)
  }
];

// 更新应用AI建议的方法
applyAiRecommendation() {
  const level = this.currentSales.level;
  
  switch(level) {
    case 'rookie':
      this.permissions[1].enabled = true; // 报价修改权限
      break;
    case 'silver':
      this.permissions[3].enabled = true; // 高级分析报告
      break;
    case 'gold':
      this.permissions[4].enabled = true; // 跨区域客户
      break;
  }
  
  alert(`已应用AI建议，${this.currentSales.name}的权限已更新`);
}
  
  ngOnInit() {
    this.initChart();
  }

  get filteredSales() {
    if (!this.activeFilter) return this.sales;
    return this.sales.filter(s => s.level === this.activeFilter);
  }

  initChart() {
  this.chartOptions = {
    backgroundColor: 'transparent',
    tooltip: {
      trigger: 'axis',
      axisPointer: {
        type: 'shadow'
      },
      backgroundColor: 'rgba(15, 23, 42, 0.9)',
      borderColor: 'rgba(255, 255, 255, 0.1)',
      borderWidth: 1,
      textStyle: {
        color: '#e2e8f0'
      },
      formatter: '{b}: {c}万元'
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      top: '10%',
      containLabel: true
    },
    xAxis: {
      type: 'value',
      axisLine: {
        lineStyle: {
          color: 'rgba(0, 0, 0, 0.1)'
        }
      },
      axisLabel: {
        color: '#64748b',
        formatter: '{value}万'
      },
      splitLine: {
        lineStyle: {
          color: 'rgba(0, 0, 0, 0.05)'
        }
      },
      name: '平均月业绩',
      nameTextStyle: {
        color: '#64748b',
        padding: [0, 0, 0, 40]
      }
    },
    yAxis: {
      type: 'category',
      data: ['实习销售', '白银销售', '黄金销售', '铂金销售', '钻石销售'],
      axisLine: {
        lineStyle: {
          color: 'rgba(0, 0, 0, 0.1)'
        }
      },
      axisLabel: {
        color: '#64748b',
        fontWeight: 'bold'
      },
      axisTick: {
        show: false
      }
    },
    series: [
      {
        name: '平均月业绩',
        type: 'bar',
        data: [8.2, 22.5, 45.8, 78.3, 125.6],
        itemStyle: {
          color: (params: any) => {
            const colors = [
              'rgba(59, 130, 246, 0.8)',
              'rgba(148, 163, 184, 0.8)',
              'rgba(245, 158, 11, 0.8)',
              'rgba(129, 140, 248, 0.8)',
              'rgba(34, 211, 238, 0.8)'
            ];
            return colors[params.dataIndex];
          },
          borderColor: (params: any) => {
            const colors = [
              'rgb(59, 130, 246)',
              'rgb(148, 163, 184)',
              'rgb(245, 158, 11)',
              'rgb(129, 140, 248)',
              'rgb(34, 211, 238)'
            ];
            return colors[params.dataIndex];
          },
          borderWidth: 2,
          borderRadius: [4, 4, 0, 0],
          shadowColor: 'rgba(0, 0, 0, 0.1)',
          shadowBlur: 5,
          shadowOffsetY: 2
        },
        label: {
          show: true,
          position: 'right',
          color: '#64748b',
          formatter: '{c}万',
          fontWeight: 'bold'
        },
        barWidth: '40%',
        emphasis: {
          itemStyle: {
            shadowColor: 'rgba(0, 0, 0, 0.2)',
            shadowBlur: 10,
            shadowOffsetY: 3
          }
        },
        animationType: 'scale',
        animationEasing: 'elasticOut',
        animationDelay: function (idx: number) {
          return idx * 100;
        }
      }
    ],
    animationDuration: 1000
  };
}

  setFilter(level: string) {
    this.activeFilter = this.activeFilter === level ? null : level;
  }

  refreshData() {
    // 模拟数据刷新
    alert('数据已刷新');
  }

  openPermissionModal(sales: any) {
    this.currentSales = sales;
    this.showModal = true;
  }

  closeModal() {
    this.showModal = false;
  }

  saveSettings() {
    this.closeModal();
    alert('权限设置已保存！');
  }

  

  aiRecommend() {
    alert('AI正在分析团队数据，推荐最优权限配置...\n\n结果：建议将3名白银销售升级为黄金销售权限');
  }

  addSales() {
    alert('添加新销售功能已打开，请填写销售信息');
  }

  viewDetails(sales: any) {
    alert(`查看${sales.name}的详细业绩分析`);
  }

  exportChart() {
    alert('图表数据已导出');
  }

  refreshChart() {
    alert('图表数据已更新');
  }

  getAiRecommendation(level: string) {
    switch(level) {
      case 'rookie':
        return 'AI建议：根据该销售表现，建议升级为<span class="ai-highlight">白银销售</span>权限级别';
      case 'silver':
        return 'AI建议：根据该销售表现，建议升级为<span class="ai-highlight">黄金销售</span>权限级别';
      case 'gold':
        return 'AI建议：根据该销售表现，建议升级为<span class="ai-highlight">铂金销售</span>权限级别';
      case 'platinum':
        return 'AI建议：根据该销售表现，建议升级为<span class="ai-highlight">钻石销售</span>权限级别';
      default:
        return 'AI建议：该销售已达到最高权限级别，表现优秀';
    }
  }

  getProgressColor(level: string) {
    switch(level) {
      case 'rookie': return '#3b82f6';
      case 'silver': return '#94a3b8';
      case 'gold': return '#f59e0b';
      case 'platinum': return '#818cf8';
      case 'diamond': return '#22d3ee';
      default: return '#3b82f6';
    }
  }

  sales = [
    {
      id: 1,
      name: '张雨欣',
      joinDate: '2023-08-15',
      level: 'rookie',
      levelName: '实习销售',
      avatar: 'https://randomuser.me/api/portraits/women/44.jpg',
      performance: '¥24,500',
      successRate: '58%',
      clients: '12',
      trainingProgress: 65,
      aiAssessment: 42
    },
    {
      id: 2,
      name: '王建国',
      joinDate: '2022-11-03',
      level: 'silver',
      levelName: '白银销售',
      avatar: 'https://randomuser.me/api/portraits/men/32.jpg',
      performance: '¥68,200',
      successRate: '76%',
      clients: '21',
      satisfaction: 88,
      aiAssessment: 78
    },
    {
      id: 3,
      name: '李思琪',
      joinDate: '2021-05-22',
      level: 'gold',
      levelName: '黄金销售',
      avatar: 'https://randomuser.me/api/portraits/women/68.jpg',
      performance: '¥128,400',
      successRate: '84%',
      clients: '29',
      vipClients: 42,
      aiAssessment: 92
    },
    {
      id: 4,
      name: '陈志强',
      joinDate: '2020-03-14',
      level: 'platinum',
      levelName: '铂金销售',
      avatar: 'https://randomuser.me/api/portraits/men/75.jpg',
      performance: '¥210,800',
      successRate: '91%',
      clients: '18',
      avgPrice: 85,
      aiAssessment: 97
    },
    {
      id: 5,
      name: '赵雅芝',
      joinDate: '2019-08-07',
      level: 'diamond',
      levelName: '钻石销售',
      avatar: 'https://randomuser.me/api/portraits/women/26.jpg',
      performance: '¥356,700',
      successRate: '96%',
      clients: '15',
      repurchaseRate: 63,
      aiAssessment: 99
    }
  ];
}